KeyPrefix

Struct KeyPrefix 

pub struct KeyPrefix { /* private fields */ }
A string which should be prefixed to an identifier to generate a database key.

Example

use redis_work_queue::KeyPrefix;

let cv_key = KeyPrefix::from("cv:");
// ...
let cv_id = "abcdef-123456";
assert_eq!(cv_key.of(cv_id), "cv:abcdef-123456");
// let cv_info = db.get(cv_key.of(cv_id));

Implementations

Source

impl KeyPrefix

pub fn new(prefix: String) -> KeyPrefix

pub fn of(&self, name: &str) -> String

Returns the result of prefixing self onto name.

pub fn and(&self, other: &str) -> KeyPrefix

Returns the result of prefixing self onto other as a new KeyPrefix.

This is like KeyPrefix::concat except it only borrows self.

pub fn concat(self, other: &str) -> KeyPrefix

Returns the result of prefixing self onto other as a new KeyPrefix.

This is like KeyPrefix::and except it moves self.